/*  libfreenet
 *  Copyright 2001 Steven Hazel <sah@thalassocracy.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef __FN_URI_H__
#define __FN_URI_H__

#include <client.h>

int freenet_parse_request_uri (freenet_key *key, unsigned char *uri);
int freenet_parse_insert_uri (freenet_key *key, unsigned char *uri);
int freenet_parse_msk (unsigned char *mskuri, unsigned char *uri,
                       unsigned char *docname);
void freenet_get_uri (freenet_key *key, unsigned char *uri);

#endif /* __FN_URI_H__ */
